@@ -1,4 +1,5 @@
-use Map::Metro::Standard::Moops;
+use feature ':5.20';
+use Moops;
 
 library  Map::Metro::Types
 
@@ -16,8 +17,6 @@ declares Connection,
          Transfer
     {
 
-    use Type::Utils -all;
-
     class_type Connection   => { class => 'Map::Metro::Graph::Connection' };
     class_type Line         => { class => 'Map::Metro::Graph::Line' };
     class_type LineStation  => { class => 'Map::Metro::Graph::LineStation' };
